==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/UserDetails.java <==
package com.example.model;

/**
 * Model for UserDetails
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "UserDetails", description = "Model for UserDetails")
@javax.xml.bind.annotation.XmlRootElement(name = "UserDetails")
public class UserDetails implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.Address address = null;
	private java.time.LocalDate dateOfBirth = null;
	private java.time.LocalDate dateOfExpiry = null;
	private java.lang.String firstName = null;
	private java.lang.String lastName = null;
	private java.lang.String licenceNumber = null;
	private java.lang.String middleName = null;
	private java.lang.String passportNumber = null;
	
	/**
	 * Model for Address
	 */
	public UserDetails address(com.example.model.Address address) {
		setAddress(address);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for Address")
	@com.fasterxml.jackson.annotation.JsonProperty("address")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.Address getAddress() {
		return this.address;
	}
	public void setAddress(com.example.model.Address address) {
		this.address = address;
	}
	
	/**
	 */
	public UserDetails dateOfBirth(java.time.LocalDate dateOfBirth) {
		setDateOfBirth(dateOfBirth);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_birth")
	public java.time.LocalDate getDateOfBirth() {
		return this.dateOfBirth;
	}
	public void setDateOfBirth(java.time.LocalDate dateOfBirth) {
		this.dateOfBirth = dateOfBirth;
	}
	
	/**
	 */
	public UserDetails dateOfExpiry(java.time.LocalDate dateOfExpiry) {
		setDateOfExpiry(dateOfExpiry);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_expiry")
	public java.time.LocalDate getDateOfExpiry() {
		return this.dateOfExpiry;
	}
	public void setDateOfExpiry(java.time.LocalDate dateOfExpiry) {
		this.dateOfExpiry = dateOfExpiry;
	}
	
	/**
	 */
	public UserDetails firstName(java.lang.String firstName) {
		setFirstName(firstName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("first_name")
	public java.lang.String getFirstName() {
		return this.firstName;
	}
	public void setFirstName(java.lang.String firstName) {
		this.firstName = firstName;
	}
	
	/**
	 */
	public UserDetails lastName(java.lang.String lastName) {
		setLastName(lastName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("last_name")
	public java.lang.String getLastName() {
		return this.lastName;
	}
	public void setLastName(java.lang.String lastName) {
		this.lastName = lastName;
	}
	
	/**
	 */
	public UserDetails licenceNumber(java.lang.String licenceNumber) {
		setLicenceNumber(licenceNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_number")
	public java.lang.String getLicenceNumber() {
		return this.licenceNumber;
	}
	public void setLicenceNumber(java.lang.String licenceNumber) {
		this.licenceNumber = licenceNumber;
	}
	
	/**
	 */
	public UserDetails middleName(java.lang.String middleName) {
		setMiddleName(middleName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("middle_name")
	public java.lang.String getMiddleName() {
		return this.middleName;
	}
	public void setMiddleName(java.lang.String middleName) {
		this.middleName = middleName;
	}
	
	/**
	 */
	public UserDetails passportNumber(java.lang.String passportNumber) {
		setPassportNumber(passportNumber);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("passport_number")
	public java.lang.String getPassportNumber() {
		return this.passportNumber;
	}
	public void setPassportNumber(java.lang.String passportNumber) {
		this.passportNumber = passportNumber;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		UserDetails userDetails = (UserDetails) o;
		return java.util.Objects.equals(this.address, userDetails.address)
				&& java.util.Objects.equals(this.dateOfBirth, userDetails.dateOfBirth)
				&& java.util.Objects.equals(this.dateOfExpiry, userDetails.dateOfExpiry)
				&& java.util.Objects.equals(this.firstName, userDetails.firstName)
				&& java.util.Objects.equals(this.lastName, userDetails.lastName)
				&& java.util.Objects.equals(this.licenceNumber, userDetails.licenceNumber)
				&& java.util.Objects.equals(this.middleName, userDetails.middleName)
				&& java.util.Objects.equals(this.passportNumber, userDetails.passportNumber);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.address, this.dateOfBirth, this.dateOfExpiry, this.firstName, this.lastName, this.licenceNumber, this.middleName, this.passportNumber);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class UserDetails {\n");
		
		sb.append("    address: ").append(toIndentedString(this.address)).append("\n");
		sb.append("    dateOfBirth: ").append(toIndentedString(this.dateOfBirth)).append("\n");
		sb.append("    dateOfExpiry: ").append(toIndentedString(this.dateOfExpiry)).append("\n");
		sb.append("    firstName: ").append(toIndentedString(this.firstName)).append("\n");
		sb.append("    lastName: ").append(toIndentedString(this.lastName)).append("\n");
		sb.append("    licenceNumber: ").append(toIndentedString(this.licenceNumber)).append("\n");
		sb.append("    middleName: ").append(toIndentedString(this.middleName)).append("\n");
		sb.append("    passportNumber: ").append(toIndentedString(this.passportNumber)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/UserDetails.java <==
package com.example.model;

/**
 * Model for UserDetails
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "UserDetails", description = "Model for UserDetails")
@javax.xml.bind.annotation.XmlRootElement(name = "UserDetails")
public class UserDetails implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.Address address = null;
	private java.time.LocalDate dateOfBirth = null;
	private java.time.LocalDate dateOfExpiry = null;
	private java.lang.String firstName = null;
	private java.lang.String lastName = null;
	private java.lang.String licenceNumber = null;
	private java.lang.String middleName = null;
	private java.lang.String passportNumber = null;
	
	/**
	 * Model for Address
	 */
	public UserDetails address(com.example.model.Address address) {
		setAddress(address);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "address", description = "Model for Address")
	@com.fasterxml.jackson.annotation.JsonProperty("address")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.Address getAddress() {
		return this.address;
	}
	public void setAddress(com.example.model.Address address) {
		this.address = address;
	}
	
	/**
	 */
	public UserDetails dateOfBirth(java.time.LocalDate dateOfBirth) {
		setDateOfBirth(dateOfBirth);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "date_of_birth")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_birth")
	public java.time.LocalDate getDateOfBirth() {
		return this.dateOfBirth;
	}
	public void setDateOfBirth(java.time.LocalDate dateOfBirth) {
		this.dateOfBirth = dateOfBirth;
	}
	
	/**
	 */
	public UserDetails dateOfExpiry(java.time.LocalDate dateOfExpiry) {
		setDateOfExpiry(dateOfExpiry);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "date_of_expiry")
	@com.fasterxml.jackson.annotation.JsonProperty("date_of_expiry")
	public java.time.LocalDate getDateOfExpiry() {
		return this.dateOfExpiry;
	}
	public void setDateOfExpiry(java.time.LocalDate dateOfExpiry) {
		this.dateOfExpiry = dateOfExpiry;
	}
	
	/**
	 */
	public UserDetails firstName(java.lang.String firstName) {
		setFirstName(firstName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "first_name")
	@com.fasterxml.jackson.annotation.JsonProperty("first_name")
	public java.lang.String getFirstName() {
		return this.firstName;
	}
	public void setFirstName(java.lang.String firstName) {
		this.firstName = firstName;
	}
	
	/**
	 */
	public UserDetails lastName(java.lang.String lastName) {
		setLastName(lastName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "last_name")
	@com.fasterxml.jackson.annotation.JsonProperty("last_name")
	public java.lang.String getLastName() {
		return this.lastName;
	}
	public void setLastName(java.lang.String lastName) {
		this.lastName = lastName;
	}
	
	/**
	 */
	public UserDetails licenceNumber(java.lang.String licenceNumber) {
		setLicenceNumber(licenceNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "licence_number")
	@com.fasterxml.jackson.annotation.JsonProperty("licence_number")
	public java.lang.String getLicenceNumber() {
		return this.licenceNumber;
	}
	public void setLicenceNumber(java.lang.String licenceNumber) {
		this.licenceNumber = licenceNumber;
	}
	
	/**
	 */
	public UserDetails middleName(java.lang.String middleName) {
		setMiddleName(middleName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "middle_name")
	@com.fasterxml.jackson.annotation.JsonProperty("middle_name")
	public java.lang.String getMiddleName() {
		return this.middleName;
	}
	public void setMiddleName(java.lang.String middleName) {
		this.middleName = middleName;
	}
	
	/**
	 */
	public UserDetails passportNumber(java.lang.String passportNumber) {
		setPassportNumber(passportNumber);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "passport_number")
	@com.fasterxml.jackson.annotation.JsonProperty("passport_number")
	public java.lang.String getPassportNumber() {
		return this.passportNumber;
	}
	public void setPassportNumber(java.lang.String passportNumber) {
		this.passportNumber = passportNumber;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		UserDetails userDetails = (UserDetails) o;
		return java.util.Objects.equals(this.address, userDetails.address)
				&& java.util.Objects.equals(this.dateOfBirth, userDetails.dateOfBirth)
				&& java.util.Objects.equals(this.dateOfExpiry, userDetails.dateOfExpiry)
				&& java.util.Objects.equals(this.firstName, userDetails.firstName)
				&& java.util.Objects.equals(this.lastName, userDetails.lastName)
				&& java.util.Objects.equals(this.licenceNumber, userDetails.licenceNumber)
				&& java.util.Objects.equals(this.middleName, userDetails.middleName)
				&& java.util.Objects.equals(this.passportNumber, userDetails.passportNumber);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.address, this.dateOfBirth, this.dateOfExpiry, this.firstName, this.lastName, this.licenceNumber, this.middleName, this.passportNumber);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class UserDetails {\n");
		
		sb.append("    address: ").append(toIndentedString(this.address)).append("\n");
		sb.append("    dateOfBirth: ").append(toIndentedString(this.dateOfBirth)).append("\n");
		sb.append("    dateOfExpiry: ").append(toIndentedString(this.dateOfExpiry)).append("\n");
		sb.append("    firstName: ").append(toIndentedString(this.firstName)).append("\n");
		sb.append("    lastName: ").append(toIndentedString(this.lastName)).append("\n");
		sb.append("    licenceNumber: ").append(toIndentedString(this.licenceNumber)).append("\n");
		sb.append("    middleName: ").append(toIndentedString(this.middleName)).append("\n");
		sb.append("    passportNumber: ").append(toIndentedString(this.passportNumber)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
